@@ -1,9 +1,9 @@
 package Egg::Const;
 #
 # Copyright 2006 Bee Flag, Corp. All Rights Reserved.
-# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Const.pm 185 2007-02-17 07:18:18Z lushe $
+# $Id: Const.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 use warnings;
@@ -55,11 +55,12 @@ There is no explained thing.
 
 =head1 SEE ALSO
 
-L<Egg::Release>, L<Egg::D>
+L<Egg::Dispatch>,
+L<Egg::Release>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>
+Masatoshi Mizuno, E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
