@@ -1,9 +1,9 @@
 package Egg::Request::FastCGI;
 #
 # Copyright (C) 2007 Bee Flag, Corp, All Rights Reserved.
-# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: FastCGI.pm 217 2007-02-20 13:11:17Z lushe $
+# $Id: FastCGI.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 use warnings;
@@ -122,7 +122,7 @@ L<Egg::Release>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
